==> libwpd-0.8.6.tar.bz2: libwpd-0.8.6/src/lib/WP5GeneralPacketData.h <==
/* libwpd
 * Copyright (C) 2005 Fridrich Strba (fridrich.strba@bluewin.ch)
 *  
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * For further information visit http://libwpd.sourceforge.net
 */

/* "This product is not manufactured, approved, or supported by 
 * Corel Corporation or Corel Corporation Limited."
 */

#ifndef WP6PREFIXDATAPACKET_H
#define WP6PREFIXDATAPACKET_H
#include <stdlib.h>
#include "WPXParser.h"

class WP5GeneralPacketIndex;

class WP5GeneralPacketData
{
public:
	WP5GeneralPacketData(WPXInputStream * input);	
	virtual ~WP5GeneralPacketData() {}

	static WP5GeneralPacketData * constructGeneralPacketData(WPXInputStream * input, WP5GeneralPacketIndex *packetIndex);

protected:
	virtual void _readContents(WPXInputStream *input, uint32_t dataSize) = 0;
 	virtual void _read(WPXInputStream *input, uint32_t dataOffset, uint32_t dataSize);
};

#endif /* WP6PREFIXDATAPACKET_H */

==> libwpd-0.8.9.tar.bz2: libwpd-0.8.9/src/lib/WP5GeneralPacketData.h <==
/* libwpd
 * Copyright (C) 2005 Fridrich Strba (fridrich.strba@bluewin.ch)
 *  
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 *
 * For further information visit http://libwpd.sourceforge.net
 */

/* "This product is not manufactured, approved, or supported by 
 * Corel Corporation or Corel Corporation Limited."
 */

#ifndef WP5GENERALPACKETDATA_H
#define WP5GENERALPACKETDATA_H
#include "WPXParser.h"
#include "libwpd_types.h"

class WP5GeneralPacketIndex;

class WP5GeneralPacketData
{
public:
	WP5GeneralPacketData(WPXInputStream * input);	
	virtual ~WP5GeneralPacketData() {}

	static WP5GeneralPacketData * constructGeneralPacketData(WPXInputStream * input, WP5GeneralPacketIndex *packetIndex);

protected:
	virtual void _readContents(WPXInputStream *input, uint32_t dataSize) = 0;
 	virtual void _read(WPXInputStream *input, uint32_t dataOffset, uint32_t dataSize);
};

#endif /* WP5GENERALPACKETDATA_H */
